@@ -2,11 +2,9 @@ use std::{
     cell::RefCell, fmt, marker::PhantomData, pin::Pin, rc::Rc, task::Context, task::Poll,
 };
 
-use bytes::{Bytes, BytesMut};
-use ntex_codec::{Decoder, Encoder};
-
 use super::{Codec, Frame, Message, ProtocolError};
-use crate::{Sink, Stream};
+use crate::util::{Bytes, BytesMut};
+use crate::{codec::Decoder, codec::Encoder, Sink, Stream};
 
 /// Stream error
 #[derive(Debug, Display)]
@@ -25,14 +23,14 @@ impl<E: fmt::Debug> From<ProtocolError> for StreamError<E> {
 }
 
 pin_project_lite::pin_project! {
-/// Stream ws protocol decoder.
-pub struct StreamDecoder<S, E> {
-    #[pin]
-    stream: S,
-    codec: Codec,
-    buf: BytesMut,
-    _t: PhantomData<E>,
-}
+    /// Stream ws protocol decoder.
+    pub struct StreamDecoder<S, E> {
+        #[pin]
+        stream: S,
+        codec: Codec,
+        buf: BytesMut,
+        _t: PhantomData<E>,
+    }
 }
 
 impl<S, E> StreamDecoder<S, E> {
@@ -89,13 +87,13 @@ where
 }
 
 pin_project_lite::pin_project! {
-/// Stream ws protocol decoder.
-#[derive(Clone)]
-pub struct StreamEncoder<S> {
-    #[pin]
-    sink: S,
-    codec: Rc<RefCell<Codec>>,
-}
+    /// Stream ws protocol decoder.
+    #[derive(Clone)]
+    pub struct StreamEncoder<S> {
+        #[pin]
+        sink: S,
+        codec: Rc<RefCell<Codec>>,
+    }
 }
 
 impl<S> StreamEncoder<S> {
@@ -170,10 +168,10 @@ where
 
 #[cfg(test)]
 mod tests {
-    use bytestring::ByteString;
-
     use super::*;
-    use crate::{channel::mpsc, util::next, util::poll_fn, util::send};
+    use crate::{
+        channel::mpsc, util::next, util::poll_fn, util::send, util::ByteString,
+    };
 
     #[crate::rt_test]
     async fn test_decoder() {
