@@ -1,10 +1,8 @@
 use std::io::{self, Read, Write};
 use std::pin::Pin;
 use std::task::{Context, Poll};
-use std::time::Duration;
 
 use brotli2::write::{BrotliDecoder, BrotliEncoder};
-use bytes::Bytes;
 use derive_more::Display;
 use flate2::read::GzDecoder;
 use flate2::write::{GzEncoder, ZlibDecoder, ZlibEncoder};
@@ -18,7 +16,8 @@ use ntex::http::header::{
     TRANSFER_ENCODING,
 };
 use ntex::http::{Method, StatusCode};
-use ntex::rt::time::{sleep, Sleep};
+use ntex::time::{sleep, Millis, Seconds, Sleep};
+use ntex::util::Bytes;
 
 use ntex::web::middleware::Compress;
 use ntex::web::{
@@ -50,7 +49,7 @@ const STR: &str = "Hello World Hello World Hello World Hello World Hello World \
 struct TestBody {
     data: Bytes,
     chunk_size: usize,
-    delay: Pin<Box<Sleep>>,
+    delay: Sleep,
 }
 
 impl TestBody {
@@ -58,7 +57,7 @@ impl TestBody {
         TestBody {
             data,
             chunk_size,
-            delay: Box::pin(sleep(std::time::Duration::from_millis(10))),
+            delay: sleep(Millis(10)),
         }
     }
 }
@@ -72,7 +71,7 @@ impl futures::Stream for TestBody {
     ) -> Poll<Option<Self::Item>> {
         ready!(Pin::new(&mut self.delay).poll(cx));
 
-        self.delay = Box::pin(sleep(std::time::Duration::from_millis(10)));
+        self.delay = sleep(Millis(10));
         let chunk_size = std::cmp::min(self.chunk_size, self.data.len());
         let chunk = self.data.split_to(chunk_size);
         if chunk.is_empty() {
@@ -883,7 +882,7 @@ async fn test_reading_deflate_encoding_large_random_rustls() {
     // client request
     let req = srv
         .post("/")
-        .timeout(Duration::from_millis(10000))
+        .timeout(Millis(10_000))
         .header(CONTENT_ENCODING, "deflate")
         .send_stream(TestBody::new(Bytes::from(enc), 1024));
 
@@ -934,7 +933,7 @@ async fn test_reading_deflate_encoding_large_random_rustls_h1() {
     // client request
     let req = srv
         .post("/")
-        .timeout(Duration::from_millis(10000))
+        .timeout(Millis(10_000))
         .header(CONTENT_ENCODING, "deflate")
         .send_stream(TestBody::new(Bytes::from(enc), 1024));
 
@@ -985,7 +984,7 @@ async fn test_reading_deflate_encoding_large_random_rustls_h2() {
     // client request
     let req = srv
         .post("/")
-        .timeout(Duration::from_millis(10000))
+        .timeout(Millis(10_000))
         .header(CONTENT_ENCODING, "deflate")
         .send_stream(TestBody::new(Bytes::from(enc), 1024));
 
@@ -1055,7 +1054,7 @@ async fn test_server_cookies() {
 async fn test_slow_request() {
     use std::net;
 
-    let srv = test::server_with(test::config().client_timeout(1), || {
+    let srv = test::server_with(test::config().client_timeout(Seconds(1)), || {
         App::new()
             .service(web::resource("/").route(web::to(|| async { HttpResponse::Ok() })))
     });
